﻿/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'fa', {
	acccessKey: 'کلید دستیابی',
	advanced: 'پیشرفته',
	advisoryContentType: 'نوع محتوای کمکی',
	advisoryTitle: 'عنوان کمکی',
	anchor: {
		toolbar: 'گنجاندن/ویرایش لینک',
		menu: 'ویرایش لینک',
		title: 'ویژگی​های لینک',
		name: 'نام لینک',
		errorName: 'لطفا نام لنگر را بنویسید',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'حذف لینک'
	},
	anchorId: 'با شناسهٴ المان',
	anchorName: 'با نام لینک ',
	charset: 'نویسه​گان منبع پیوند شده',
	cssClasses: 'کلاس​های شیوه​نامه (Style sheet)',
	download: 'بارگیری اجباری',
	displayText: 'نمایش متن',
	emailAddress: 'نشانی پست الکترونیکی',
	emailBody: 'متن پیام',
	emailSubject: 'موضوع پیام',
	id: 'شناسه',
	info: 'اطلاعات پیوند',
	langCode: 'کد زبان',
	langDir: 'جهت​نمای زبان',
	langDirLTR: 'چپ به راست (LTR)',
	langDirRTL: 'راست به چپ (RTL)',
	menu: 'ویرایش پیوند',
	name: 'نام',
	noAnchors: '(در این سند لینکی دردسترس نیست)',
	noEmail: 'لطفا نشانی پست الکترونیکی را بنویسید',
	noUrl: 'لطفا آدرس پیوند را بنویسید',
	noTel: 'لطفا شماره تلفن را وارد کنید',
	other: '<سایر>',
	phoneNumber: 'شماره تلفن',
	popupDependent: 'وابسته (Netscape)',
	popupFeatures: 'ویژگی​های پنجره ی پاپاپ',
	popupFullScreen: 'تمام صفحه (IE)',
	popupLeft: 'موقعیت چپ',
	popupLocationBar: 'نوار موقعیت',
	popupMenuBar: 'نوار منو',
	popupResizable: 'قابل تغییر اندازه',
	popupScrollBars: 'میله​های پیمایش',
	popupStatusBar: 'نوار وضعیت',
	popupToolbar: 'نوار ابزار',
	popupTop: 'موقعیت بالا',
	rel: 'وابستگی',
	selectAnchor: 'یک لینک برگزینید',
	styles: 'شیوه (style)',
	tabIndex: 'نمایهٴ دسترسی با برگه',
	target: 'مقصد',
	targetFrame: '<قاب>',
	targetFrameName: 'نام قاب مقصد',
	targetPopup: '<پنجرهٴ پاپاپ>',
	targetPopupName: 'نام پنجره ی پاپاپ',
	title: 'پیوند',
	toAnchor: 'لنگر در همین صفحه',
	toEmail: 'پست الکترونیکی',
	toUrl: 'آدرس',
	toPhone: 'تلفن',
	toolbar: 'گنجاندن/ویرایش پیوند',
	type: 'نوع پیوند',
	unlink: 'برداشتن پیوند',
	upload: 'انتقال به سرور'
} );
